@@ -10,7 +10,7 @@ use DateTime::Helpers;
 
 BEGIN
 {
-    $VERSION = '0.35';
+    $VERSION = '0.36';
 
     my $loaded = 0;
     unless ( $ENV{PERL_DATETIME_PP} )
@@ -74,8 +74,8 @@ require DateTime::Infinite;
 
 use constant MAX_NANOSECONDS => 1_000_000_000;  # 1E9 = almost 32 bits
 
-use constant INFINITY     =>       100 ** 100 ** 100 ;
-use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
+use constant INFINITY     =>       100 ** 1000;
+use constant NEG_INFINITY => -1 * (100 ** 1000);
 use constant NAN          => INFINITY - INFINITY;
 
 use constant SECONDS_PER_DAY => 86400;
